@@ -109,6 +109,23 @@ def _find_quote_char_in_part(part):
     return quote_char
 
 
+def find_service_and_method_in_event_name(event_name):
+    """
+    Grabs the service name and the operation name from an event name.
+    This is making the assumption that the event name is in the form
+    event.service.operation.
+    """
+    split_event = event_name.split('.')[1:]
+    service_name = None
+    if len(split_event) > 0:
+        service_name = split_event[0]
+
+    operation_name = None
+    if len(split_event) > 1:
+        operation_name = split_event[1]
+    return service_name, operation_name
+
+
 def json_encoder(obj):
     """JSON encoder that formats datetimes as ISO8601 format."""
     if isinstance(obj, datetime.datetime):
@@ -124,3 +141,8 @@ def ignore_ctrl_c():
         yield
     finally:
         signal.signal(signal.SIGINT, original)
+
+
+def emit_top_level_args_parsed_event(session, args):
+    session.emit(
+        'top-level-args-parsed', parsed_args=args, session=session)
